# Show running .NET-Version
# Stop-Process -Name notepad -Force -ErrorAction SilentlyContinue
$execruntime = [System.Reflection.Assembly]::GetExecutingAssembly().ImageRuntimeVersion
#
$ExportPath = $env:TEMP
$ExportFile = "network-info-$env:Username@$env:computername.txt"
Remove-Item $ExportPath\$ExportFile -Force -ErrorAction SilentlyContinue
#

# ---- Ausgabe --- START ------ 
$DateTXT = Get-Date  -format "dd.MM.yyyy - hh:mm:ss tt"
Write-Output "------------------------------------------------------------------" | Out-File "$ExportPath\$ExportFile" -Encoding utf8
Write-Output "Network-Info Tool - Ver. 1.0.1 (15.10.2023) / .NET Runtime $execruntime" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Download https:\\www.hekret.de\pcinfo" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "------------------------------------------------------------------`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
# Write-Output "`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Erstellt von Benutzer '$env:userdomain\$env:USERNAME @ $env:computername'`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Write-Output "Datensatz erstellt am $DateTXT`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#

Write-Host "------------------------------------------------------------------"
Write-Host "Network-Info Tool - Ver. 1.0.1 (15.10.2023) / .NET Runtime $execruntime"
Write-Host "Download https:\\www.hekret.de\pcinfo"
Write-Host "------------------------------------------------------------------`r`n"

# --- Info Machine / User --- START ---
$machinename = (Get-CimInstance -Class:Win32_Computersystem).Name
$domain = (Get-CimInstance Win32_ComputerSystem).Domain

# ActiveDirectory Site abfragen und Fehler abfangen.
try {
    $adsite = [System.DirectoryServices.ActiveDirectory.ActiveDirectorySite]::GetComputerSite().Name
    }
    catch
    {
    # Write-Host $PSItem.Exception.Message
    Set-Variable -Name adsite -Value "-"
    }
#
#
$dr = Get-CimInstance -Class win32_computersystem | Select-Object -ExpandProperty domainrole
$domainrole = switch ($dr) {
    0 {"Standalone Workstation"} 
    1 {"Member Workstation"} 
    2 {"Standalone Server"} 
    3 {"Member Server"} 
    4 {"Backup Domain Controller"} 
    5 {"Primary Domain Controller"} 
    default {"Unknown"} 
    } # end switch



write-Output "
Domain Machine Info:`
    Computername: ............... $machinename`
    ActiveDirectory: ............ $domain`
    Site: ....................... $adsite`
    Domain Role: ................ $domainrole`
`
Domain User Info:`
    ActiveDirectory: ............ $env:userdomain`
    LogonServer: ................ $env:logonserver`
    UserName: ................... $env:USERNAME`
    `
    `
    " | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append

# --- Info Machine / User --- END ---

# Write-Host "Status:`n"
Write-Host "collecting Data ...  / sammle Daten ...`r`n"
#
# Update 2022-05-06 - IP-List fixed
# -------------------  Hardware Info ---------------- START -------------------
#
Write-Host "Network + DNS-Names / Netzwerk + DNS-Name`n"
Write-Output "----- Network + DNS-Names / Netzwerk + DNS-Name ------ START -----" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
#
Import-Module -Name NetAdapter

# List all Network-Adapters
Get-NetAdapter | `
		# Where-Object -FilterScript { ($PSItem.MacAddress -gt "0") } | `
        # Sort-Object -Property Name -Descending  | `
        Sort-Object -Property Status,Name -Descending  | `
		Format-Table -AutoSize | Out-File  -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append

# active IP-Addresses
Get-NetAdapter | Where-Object -FilterScript { `
	# ($PSItem.MacAddress -gt "0")  -and `
	($PSItem.Status -eq "Up") } -ErrorAction SilentlyContinue | get-netipaddress -ErrorAction Continue | `
	Select-Object InterfaceAlias,AddressFamily,IPAddress,PrefixOrigin,ValidLifeTime,PreferredLifeTime  | `
	Sort-Object -Property AddressFamily | Format-Table -AutoSize | Out-File  -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append

# DNS-Names
 (Get-NetAdapter | Where-Object -FilterScript { `
	# ($PSItem.MacAddress -gt "0") -and `
	($PSItem.Status -eq "Up") } | get-netipaddress -ErrorAction Continue ).IPAddress | `
	Resolve-DnsName -NoHostsFile -DnsOnly -Type PTR -ErrorAction SilentlyContinue | `
	Where-Object Type -eq 'PTR' | Format-Table -AutoSize | Out-File -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append


# Get-CimInstance -Class CIM_NetworkAdapter | Where-Object -FilterScript { `
# 	($PSItem.MacAddress -gt "0") }  | get-netipaddress -ErrorAction Continue | Select-Object InterfaceAlias,AddressFamily,IPAddress,PrefixOrigin,ValidLifeTime,PreferredLifeTime  | `
#	Format-Table -AutoSize  # | Out-File  -Width 500 -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append

#
Write-Host "------------------------------------------------------------------`r`n"
write-Output "`n`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
Write-Output "--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--/--\--`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
#

# ---- Ausgabe --- END ------ 
#
$DateTXT = Get-Date  -format "dd.MM.yyyy - hh:mm:ss tt"
Write-Output "------------------------------------------------------------------" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "Erfassung abgeschlossen: $DateTXT" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "------------------------------------------------------------------`r`n" | Out-File "$ExportPath\$ExportFile" -Encoding utf8 -Append
Write-Output "_______________ - End of File - ______________________`r`n" | Out-File -FilePath $ExportPath\$ExportFile -Encoding utf8 -Append
#
# Get-Content $ExportPath\$ExportFile
# pause
Start-Process notepad.exe $ExportPath\$ExportFile
